@@ -193,7 +193,7 @@ setMethod(".ginput",
                response == GtkResponseType["close"] ||
                response == GtkResponseType["delete-event"]) {
               dlg$Destroy()
-              invisible("")
+              invisible(NA)
             } else if(response == GtkResponseType["ok"]) {
               if(!is.null(handler)) handler(h)
               val = svalue(input)
@@ -220,8 +220,8 @@ setMethod(".gbasicdialog",
                    action = NULL,
                    ...
                    ) {
-
-
+            
+            
             ## parent
             if(!is.null(parent)) {
               parent <- getBlock(parent)
@@ -232,8 +232,8 @@ setMethod(".gbasicdialog",
             } else {
               parent <- gtkWindowNew(show=FALSE)
             }
-
-
+            
+            
             
             dlg = gtkDialog(title,
               parent=parent,
@@ -243,10 +243,10 @@ setMethod(".gbasicdialog",
             dlg$SetTitle(title)
             dlg$GrabFocus()
             dlg$GetWindow()$Raise()
-
-
+            
+            
             tag(widget,"dlg") <- dlg
-
+            
             ## group to pack widget in
             group = ggroup()
             add(group, widget, expand=TRUE)
@@ -277,4 +277,133 @@ setMethod(".gbasicdialog",
             }
             
           })
-          
+
+## with no paret
+setClass("gBasicDialogNoParentRGtk",
+         contains="gContainerRGtk",
+         prototype=prototype(new("gContainerRGtk"))
+         )
+
+setMethod(".gbasicdialognoparent",
+          signature(toolkit="guiWidgetsToolkitRGtk2"),
+          function(toolkit,
+                   title = "Dialog",
+                   parent=NULL,                   
+                   handler = NULL,
+                   action = NULL,
+                   ...
+                   ) {
+
+                        
+            dlg = gtkDialog(title,
+              parent=parent,
+              flags = 0,
+              "gtk-ok", GtkResponseType["ok"],
+              "gtk-cancel", GtkResponseType["cancel"],
+              show=FALSE)
+            dlg$SetTitle(title)
+
+            obj <- new("gBasicDialogNoParentRGtk",
+                       block=dlg, widget=dlg, toolkit=guiToolkit("RGtk2"))
+            tag(obj,"handler") <- handler
+            tag(obj,"action") <- action
+
+            return(obj)
+          })
+
+setMethod(".add",
+          signature(toolkit="guiWidgetsToolkitRGtk2",
+                    obj="gBasicDialogNoParentRGtk", value="guiWidget"),
+          function(obj, toolkit, value, ...) {
+            .add(obj, toolkit, value@widget, ...)
+          })
+setMethod(".add",
+          signature(toolkit="guiWidgetsToolkitRGtk2",
+                    obj="gBasicDialogNoParentRGtk", value="gWidgetRGtk"),
+           function(obj, toolkit, value, ...) {
+             tag(obj,"widget") <- value
+             
+             ## group to pack widget in
+             group <- gtkHBox(spacing=5)
+             group$PackStart(getBlock(value))
+            
+             ## find the area to pack the entry widget
+             dlg <- getWidget(obj)
+             dlg$GetVbox()$PackStart(group)
+            
+             dlg$GrabFocus()
+#             dlg$GetWindow()$Raise()
+
+            
+          })
+
+setMethod(".visible",
+                 signature(toolkit="guiWidgetsToolkitRGtk2",
+                           obj="gBasicDialogNoParentRGtk"),
+                 function(obj, toolkit, set=NULL, ...) {
+
+                   if(as.logical(set)) {
+
+                     dlg <- getWidget(obj)
+                     handler <- tag(obj,"handler")
+                     action <- tag(obj,"action")
+                     widget <- tag(obj,"widget")
+                     
+                     ## run in modal mode
+                     response = dlg$Run()
+
+
+                     h = list(obj=widget, action=action)
+
+                     if(response == GtkResponseType["cancel"] ||
+                        response == GtkResponseType["close"] ||
+                        response == GtkResponseType["delete-event"]) {
+                       ## cancel action
+                       dlg$Destroy()
+                       return(FALSE)
+                     } else if(response == GtkResponseType["ok"]) {
+                       print("call handler")
+                       if(!is.null(handler))
+                         handler(h)
+                       dlg$Destroy()
+                       return(TRUE)              # was widget, but TRUE now
+                     } else {
+                       ## default action
+                       gwCat("Don't know this response")
+                       print(response)
+                       dlg$Destroy()
+                       return(invisible(NA))
+                     }
+                   } else {
+                     gwCat("gbasicdialog: call visible(obj,set=TRUE) to see.\n")
+                     return(invisible(NA))
+                   }
+                 })
+                 
+
+
+setMethod(".galert",
+          signature(toolkit="guiWidgetsToolkitRGtk2"),
+          function(toolkit,
+                   message,
+                   title = "message",
+                   delay = 3,
+                   parent=NULL,
+                   ...
+                   ) {
+            force(toolkit)
+
+            w <- gwindow(title, width=250, height=100, parent = parent)
+            g <- ggroup(cont = w)
+            l <- gbutton("  ", cont = g)
+            getToolkitWidget(l)$modifyBg(GtkStateType['normal'], color="red")
+            label <- glabel(message, cont = g, expand=TRUE)
+            font(label) <- c("weight"="bold")
+            gimage(file="close",dir="stock", cont = g, handler = function(h,...) dispose(w))
+            
+            addHandlerIdle(w, handler = function(h,...) dispose(w),
+                           interval = as.numeric(delay)*1000)
+
+            invisible(w)
+          })
+ 
